@@ -49,6 +49,12 @@ from ..version import __version__
     help="The length of the session requested from STS.",
     envvar="SYM_SESSION_LENGTH",
 )
+@click.option(
+    "--disable-caches",
+    is_flag=True,
+    help="Disables all caches.",
+    envvar="SYM_DISABLE_CACHES",
+)
 @click.make_pass_decorator(GlobalOptions, ensure=True)
 @resource_option
 @setup_segment(write_key=SegmentWriteKey)
@@ -58,6 +64,7 @@ def sym(
     saml_client_name: SAMLClientName,
     debug: bool,
     disable_analytics: bool,
+    disable_caches: bool,
     resource: str,
     aws_region: str,
     log_dir: Optional[str],
@@ -75,6 +82,7 @@ def sym(
     options.log_dir = log_dir
     options.aws_region = aws_region
     options.session_length = session_length
+    options.disable_caches = disable_caches
 
     if not Config.should_analytics():
         options.disable_analytics = True
