@@ -124,7 +124,7 @@ def loses_interactivity(fn: F) -> F:
     @click.pass_context
     @wraps(fn)
     def wrapped(context: click.Context, *args: Any, **kwargs: Any) -> Any:
-        if (resource := kwargs.get("resource")) :
+        if resource := kwargs.get("resource"):
             saml_client = SAMLClientFactory.create_saml_client(
                 resource, context.find_object(GlobalOptions)
             )
