@@ -1,6 +1,6 @@
 from typing import Optional
 
-from .params import PARAMS as PARAMS_BY_ORG
+from sym.cli.helpers.params import PARAMS as PARAMS_BY_ORG
 
 _ORGS_BY_DOMAIN = dict(map(lambda kv: (kv[1]["domain"], kv[0]), PARAMS_BY_ORG.items()))
 
