@@ -67,7 +67,7 @@ def check_ssh_version() -> bool:
 
 def get_ssh_version() -> Tuple[int, int]:
     result = subprocess.run(["ssh", "-V"], text=True, capture_output=True).stderr
-    if (match := OPENSSH_VERSION_PATTERN.search(result)) :
+    if match := OPENSSH_VERSION_PATTERN.search(result):
         return tuple(map(int, (match[1], match[2])))
     return (0, 0)
 
@@ -165,7 +165,7 @@ def _on_ssh_error(client: SAMLClient, instance: str, args: Sequence[str]):
     """
     Config.touch_instance(instance, error=True)
     opts = _parse_options_from_args(args)
-    if (vi := opts.get("controlpath")) :
+    if vi := opts.get("controlpath"):
         try:
             os.unlink(vi[0])
         except OSError as err:
@@ -182,7 +182,7 @@ def _preprocess_args(client: SAMLClient, instance: str, args: Sequence[str]) ->
     opts = _parse_options_from_args(args)
     if not Config.check_instance_ttl(instance):
         for opt in ("controlmaster", "controlpath"):
-            if (vi := opts.get(opt)) :
+            if vi := opts.get(opt):
                 del processed[vi[1] : vi[1] + 2]
 
         processed.extend(["-o", "ControlMaster=no"])
